@@ -16,16 +16,16 @@ echo "Actions=Play;Previous;Next;"
 echo ""
 echo "[Desktop Action Play]"
 echo "Exec=parole --play"
-echo "_Name=Play/Pause"
+echo "Name=Play/Pause"
 echo "Icon=media-playback-start-symbolic"
 echo ""
 echo "[Desktop Action Previous]"
 echo "Exec=parole --previous"
-echo "_Name=Previous Track"
+echo "Name=Previous Track"
 echo "Icon=media-skip-backward-symbolic"
 echo ""
 echo "[Desktop Action Next]"
 echo "Exec=parole --next"
-echo "_Name=Next Track"
+echo "Name=Next Track"
 echo "Icon=media-skip-forward-symbolic"
 echo ""
