@@ -29,7 +29,6 @@
 #include <glib.h>
 #include <gio/gio.h>
 #include <gtk/gtk.h>
-#include <gdk/gdkx.h>
 
 #include <libxfce4util/libxfce4util.h>
 
@@ -96,8 +95,9 @@ parole_power_manager_uninhibit (GDBusConnection *connection,
     if (error) {
         g_warning ("Uninhibiting power management failed: %s", error->message);
         g_error_free (error);
+    } else {
+        g_variant_unref (reply);
     }
-    g_variant_unref (reply);
 }
 
 GDBusConnection *
