@@ -262,10 +262,7 @@ int main(int argc, char **argv) {
         { NULL, },
     };
 
-#if !GLIB_CHECK_VERSION(2, 35, 0)
-    if (g_thread_supported ())
-#endif
-        dbus_threads_init_default();
+    dbus_threads_init_default();
 
     /* initialize xfconf */
     if (!xfconf_init(&error)) {
